@@ -4,6 +4,7 @@ import json
 import os
 import shutil
 import threading
+from contextlib import contextmanager
 from pathlib import Path
 from unittest.mock import patch
 
@@ -18,16 +19,33 @@ from tests import utils as testutils
 
 @pytest.fixture(scope='module')
 def httpbin():
-    httpbin = testutils.get_httpbin()
-    yield httpbin
-    httpbin.close()
+    # This module scoped Httpbin fixture uses HTTPS
+    with create_httpbin() as httpbin:
+        yield httpbin
+
+
+@contextmanager
+def create_httpbin(port=8085, use_https=True):
+    httpbin = testutils.get_httpbin(port, use_https)
+    try:
+        yield httpbin
+    finally:
+        httpbin.close()
 
 
 @pytest.fixture(scope='module')
 def httpproxy():
-    httpproxy = testutils.get_proxy()
-    yield httpproxy
-    httpproxy.close()
+    with create_httpproxy() as proxy:
+        yield proxy
+
+
+@contextmanager
+def create_httpproxy(port=8086, mode='http', auth=''):
+    httpproxy = testutils.get_proxy(port, mode, auth)
+    try:
+        yield httpproxy
+    finally:
+        httpproxy.close()
 
 
 @pytest.fixture(scope='module')
@@ -51,23 +69,27 @@ def chrome_options():
 
 @pytest.fixture
 def driver(driver_path, chrome_options):
-    driver = create_driver(driver_path, chrome_options)
-    yield driver
-    driver.quit()
+    with create_driver(driver_path, chrome_options) as driver:
+        yield driver
 
 
+@contextmanager
 def create_driver(
-        driver_path,
-        chrome_options,
-        seleniumwire_options=None,
-        desired_capabilities=None,
+    driver_path,
+    chrome_options,
+    seleniumwire_options=None,
+    desired_capabilities=None,
 ):
-    return webdriver.Chrome(
+    driver = webdriver.Chrome(
         executable_path=driver_path,
         options=chrome_options,
         seleniumwire_options=seleniumwire_options,
         desired_capabilities=desired_capabilities,
     )
+    try:
+        yield driver
+    finally:
+        driver.quit()
 
 
 def teardown_function():
@@ -81,13 +103,9 @@ def teardown_function():
     except FileNotFoundError:
         pass
 
-    shutil.rmtree(
-        Path(__file__).parent / Path('linux', 'locales'), ignore_errors=True
-    )
+    shutil.rmtree(Path(__file__).parent / Path('linux', 'locales'), ignore_errors=True)
 
-    shutil.rmtree(
-        Path(__file__).parent / 'chrome_tmp', ignore_errors=True
-    )
+    shutil.rmtree(Path(__file__).parent / 'chrome_tmp', ignore_errors=True)
 
 
 def test_capture_requests(driver, httpbin):
@@ -124,9 +142,7 @@ def test_wait_for_request_timeout(driver, httpbin):
 
 
 def test_scopes(driver, httpbin):
-    driver.scopes = [
-        '.*/anything/.*'
-    ]
+    driver.scopes = ['.*/anything/.*']
 
     driver.get(f'{httpbin}/anything/hello/world')
     driver.get(f'{httpbin}/html')
@@ -212,8 +228,6 @@ def test_update_json_post_request(driver_path, chrome_options, httpbin):
     chrome_data_dir = Path(__file__).parent / 'chrome_tmp'
     chrome_options.add_argument(f'--user-data-dir={str(chrome_data_dir)}')
 
-    driver = create_driver(driver_path, chrome_options)
-
     def interceptor(req):
         if req.method == 'POST' and req.headers['Content-Type'] == 'application/json':
             # We expect the request body to contain the JSON:
@@ -225,19 +239,18 @@ def test_update_json_post_request(driver_path, chrome_options, httpbin):
             del req.headers['Content-Length']
             req.headers['Content-Length'] = str(len(req.body))
 
-    driver.request_interceptor = interceptor
+    with create_driver(driver_path, chrome_options) as driver:
+        driver.request_interceptor = interceptor
 
-    form = Path(__file__).parent / 'jsonform.html'
-    driver.get(f'file:///{str(form)}')
-    button = driver.find_element_by_id('submit')
-    button.click()  # Makes Ajax request so need to wait for it
-    request = driver.wait_for_request('/post')
+        form = Path(__file__).parent / 'jsonform.html'
+        driver.get(f'file:///{str(form)}')
+        button = driver.find_element_by_id('submit')
+        button.click()  # Makes Ajax request so need to wait for it
+        request = driver.wait_for_request('/post')
 
-    resp_body = json.loads(request.response.body.decode('utf-8'))
+        resp_body = json.loads(request.response.body.decode('utf-8'))
 
-    assert resp_body['json'] == {'hello': 'world', 'spam': 'eggs', 'foo': 'bar'}
-
-    driver.quit()
+        assert resp_body['json'] == {'hello': 'world', 'spam': 'eggs', 'foo': 'bar'}
 
 
 def test_block_a_request(driver, httpbin):
@@ -254,9 +267,7 @@ def test_mock_a_response(driver, httpbin):
     def interceptor(req):
         if req.url == f'{httpbin}/html':
             req.create_response(
-                status_code=200,
-                headers={'Content-Type': 'text/html'},
-                body='<html>Hello World!</html>'
+                status_code=200, headers={'Content-Type': 'text/html'}, body='<html>Hello World!</html>'
             )
 
     driver.request_interceptor = interceptor
@@ -266,82 +277,45 @@ def test_mock_a_response(driver, httpbin):
 
 
 def test_mitmproxy_backend(driver_path, chrome_options, httpbin):
-    sw_options = {
-        'backend': 'mitmproxy'
-    }
+    sw_options = {'backend': 'mitmproxy'}
 
-    driver = create_driver(driver_path, chrome_options, sw_options)
-    driver.get(f'{httpbin}/html')
+    with create_driver(driver_path, chrome_options, sw_options) as driver:
+        driver.get(f'{httpbin}/html')
 
-    assert driver.last_request.response is not None
-
-    driver.quit()
+        assert driver.last_request.response is not None
 
 
 def test_upstream_http_proxy(driver_path, chrome_options, httpbin, httpproxy):
-    sw_options = {
-        'proxy': {
-            'https': f'{httpproxy}'
-        }
-    }
+    sw_options = {'proxy': {'https': f'{httpproxy}'}}
 
-    driver = create_driver(driver_path, chrome_options, sw_options)
-    driver.get(f'{httpbin}/html')
+    with create_driver(driver_path, chrome_options, sw_options) as driver:
+        driver.get(f'{httpbin}/html')
 
-    assert 'This passed through a http proxy' in driver.page_source
-
-    driver.quit()
+        assert 'This passed through a http proxy' in driver.page_source
 
 
 def test_upstream_http_proxy_basic_auth(driver_path, chrome_options, httpbin):
-    httpproxy = None
+    with create_httpproxy(port=8888, auth='test:test') as httpproxy:
+        sw_options = {'proxy': {'https': f'{httpproxy}'}}
 
-    try:
-        httpproxy = testutils.get_proxy(mode='http', port=8088, auth='test:test')
-        sw_options = {
-            'proxy': {
-                'https': f'{httpproxy}'
-            }
-        }
+        with create_driver(driver_path, chrome_options, sw_options) as driver:
+            driver.get(f'{httpbin}/html')
 
-        driver = create_driver(driver_path, chrome_options, sw_options)
-        driver.get(f'{httpbin}/html')
-
-        assert 'This passed through a authenticated http proxy' in driver.page_source
-
-        driver.quit()
-    finally:
-        if httpproxy:
-            httpproxy.close()
+            assert 'This passed through a authenticated http proxy' in driver.page_source
 
 
 def test_upstream_http_proxy_basic_auth_empty_pass(driver_path, chrome_options, httpbin):
-    httpproxy = None
+    with create_httpproxy(port=8888, auth='test:') as httpproxy:
+        sw_options = {'proxy': {'https': f'{httpproxy}'}}
 
-    try:
-        httpproxy = testutils.get_proxy(mode='http', port=8088, auth='test:')
-        sw_options = {
-            'proxy': {
-                'https': f'{httpproxy}'
-            }
-        }
+        with create_driver(driver_path, chrome_options, sw_options) as driver:
+            driver.get(f'{httpbin}/html')
 
-        driver = create_driver(driver_path, chrome_options, sw_options)
-        driver.get(f'{httpbin}/html')
-
-        assert 'This passed through a authenticated http proxy' in driver.page_source
-
-        driver.quit()
-    finally:
-        if httpproxy:
-            httpproxy.close()
+            assert 'This passed through a authenticated http proxy' in driver.page_source
 
 
 def test_upstream_http_proxy_custom_auth(driver_path, chrome_options, httpbin):
-    httpproxy = None
-
-    try:
-        httpproxy = testutils.get_proxy(mode='http', port=8088, auth='test:test')
+    with create_httpproxy(port=8088, auth='test:test'):
         sw_options = {
             'proxy': {
                 'https': 'https://localhost:8088',
@@ -349,72 +323,60 @@ def test_upstream_http_proxy_custom_auth(driver_path, chrome_options, httpbin):
             },
         }
 
-        driver = create_driver(driver_path, chrome_options, sw_options)
-        driver.get(f'{httpbin}/html')
+        with create_driver(driver_path, chrome_options, sw_options) as driver:
+            driver.get(f'{httpbin}/html')
 
-        assert 'This passed through a authenticated http proxy' in driver.page_source
-
-        driver.quit()
-    finally:
-        if httpproxy:
-            httpproxy.close()
+            assert 'This passed through a authenticated http proxy' in driver.page_source
 
 
 def test_upstream_socks_proxy(driver_path, chrome_options, httpbin, socksproxy):
     """Note that authenticated socks proxy is not supported by mitmproxy currently
     so we're only able to test unauthenticated.
     """
-    sw_options = {
-        'proxy': {
-            'https': f'{socksproxy}'
-        }
-    }
+    sw_options = {'proxy': {'https': f'{socksproxy}'}}
 
-    driver = create_driver(driver_path, chrome_options, sw_options)
-    driver.get(f'{httpbin}/html')
+    with create_driver(driver_path, chrome_options, sw_options) as driver:
+        driver.get(f'{httpbin}/html')
 
-    assert 'This passed through a socks proxy' in driver.page_source
-
-    driver.quit()
+        assert 'This passed through a socks proxy' in driver.page_source
 
 
-def test_bypass_upstream_http_proxy(driver_path, chrome_options, httpbin, httpproxy):
-    sw_options = {
-        'proxy': {
-            'https': f'{httpproxy}',
-            'no_proxy': 'localhost:8085'
-        }
-    }
+def test_bypass_upstream_proxy_when_target_http(driver_path, chrome_options, httpproxy):
+    sw_options = {'proxy': {'https': f'{httpproxy}', 'no_proxy': 'localhost:9091'}}
 
-    driver = create_driver(driver_path, chrome_options, sw_options)
-    driver.get(f'{httpbin}/html')
+    with create_httpbin(port=9091, use_https=False) as httpbin:
+        with create_driver(driver_path, chrome_options, sw_options) as driver:
+            driver.get(f'{httpbin}/html')  # Scheme is http://
 
-    assert 'This passed through a http proxy' not in driver.page_source
+            assert 'Moby-Dick' in driver.page_source
+            assert 'This passed through a http proxy' not in driver.page_source
 
-    driver.quit()
+
+def test_bypass_upstream_proxy_when_target_https(driver_path, chrome_options, httpbin, httpproxy):
+    sw_options = {'proxy': {'https': f'{httpproxy}', 'no_proxy': 'localhost:8085'}}
+
+    with create_driver(driver_path, chrome_options, sw_options) as driver:
+        driver.get(f'{httpbin}/html')  # Scheme is https://
+
+        assert 'Moby-Dick' in driver.page_source
+        assert 'This passed through a http proxy' not in driver.page_source
 
 
 def test_upstream_http_proxy_env_var(driver_path, chrome_options, httpbin, httpproxy):
     with patch.dict(os.environ, {'HTTPS_PROXY': f'{httpproxy}'}):
-        driver = create_driver(driver_path, chrome_options)
-        driver.get(f'{httpbin}/html')
+        with create_driver(driver_path, chrome_options) as driver:
+            driver.get(f'{httpbin}/html')
 
-        assert 'This passed through a http proxy' in driver.page_source
-
-        driver.quit()
+            assert 'This passed through a http proxy' in driver.page_source
 
 
 def test_no_auto_config(driver_path, chrome_options, httpbin):
-    sw_options = {
-        'auto_config': False
-    }
+    sw_options = {'auto_config': False}
 
-    driver = create_driver(driver_path, chrome_options, sw_options)
-    driver.get(f'{httpbin}/html')
+    with create_driver(driver_path, chrome_options, sw_options) as driver:
+        driver.get(f'{httpbin}/html')
 
-    assert not driver.requests
-
-    driver.quit()
+        assert not driver.requests
 
 
 def test_no_auto_config_manual_proxy(driver_path, chrome_options, httpbin):
@@ -438,33 +400,27 @@ def test_no_auto_config_manual_proxy(driver_path, chrome_options, httpbin):
         'port': 8088,
     }
 
-    driver = create_driver(
+    with create_driver(
         driver_path,
         chrome_options,
         sw_options,
         capabilities,
-    )
+    ) as driver:
 
-    driver.get(f'{httpbin}/html')
-    driver.wait_for_request('/html')
-
-    driver.quit()
+        driver.get(f'{httpbin}/html')
+        driver.wait_for_request('/html')
 
 
 def test_exclude_hosts(driver_path, chrome_options, httpbin):
     httpbin2 = testutils.get_httpbin(port=8090)
-    sw_options = {
-        'exclude_hosts': ['<-loopback>', 'localhost:8085']
-    }
+    sw_options = {'exclude_hosts': ['<-loopback>', 'localhost:8085']}
 
-    driver = create_driver(driver_path, chrome_options, sw_options)
-    driver.get(f'{httpbin}/html')
-    driver.get(f'{httpbin2}/html')
+    with create_driver(driver_path, chrome_options, sw_options) as driver:
+        driver.get(f'{httpbin}/html')
+        driver.get(f'{httpbin2}/html')
 
-    assert len(driver.requests) == 1
-    assert driver.requests[0].url == f'{httpbin2}/html'
-
-    driver.quit()
+        assert len(driver.requests) == 1
+        assert driver.requests[0].url == f'{httpbin2}/html'
 
 
 @pytest.mark.skip("Fails on GitHub Actions - chromedriver threads timeout")
@@ -473,17 +429,13 @@ def test_multiple_threads(driver_path, chrome_options, httpbin):
     threads, results = [], []
 
     def run_driver():
-        driver = create_driver(driver_path, chrome_options)
-        driver.get(f'{httpbin}/html')
-        request = driver.wait_for_request('/html')
-        results.append(request)
-        driver.quit()
+        with create_driver(driver_path, chrome_options) as driver:
+            driver.get(f'{httpbin}/html')
+            request = driver.wait_for_request('/html')
+            results.append(request)
 
     for i in range(num_threads):
-        t = threading.Thread(
-            name=f'Driver thread {i + 1}',
-            target=run_driver
-        )
+        t = threading.Thread(name=f'Driver thread {i + 1}', target=run_driver)
         threads.append(t)
         t.start()
 
@@ -494,16 +446,12 @@ def test_multiple_threads(driver_path, chrome_options, httpbin):
 
 
 def test_ignore_http_methods(driver_path, chrome_options, httpbin):
-    sw_options = {
-        'ignore_http_methods': ['GET']
-    }
+    sw_options = {'ignore_http_methods': ['GET']}
 
-    driver = create_driver(driver_path, chrome_options, sw_options)
-    driver.get(f'{httpbin}/html')
+    with create_driver(driver_path, chrome_options, sw_options) as driver:
+        driver.get(f'{httpbin}/html')
 
-    assert not driver.requests
-
-    driver.quit()
+        assert not driver.requests
 
 
 def test_address_in_use(driver_path, chrome_options, httpbin):
@@ -512,40 +460,32 @@ def test_address_in_use(driver_path, chrome_options, httpbin):
         'port': 8089,
     }
 
-    driver = create_driver(driver_path, chrome_options, sw_options)
-
-    with pytest.raises(ServerException, match='.*Address already in use.*'):
-        create_driver(driver_path, chrome_options, sw_options)
-
-    driver.quit()
+    with create_driver(driver_path, chrome_options, sw_options):
+        with pytest.raises(ServerException, match='.*Address already in use.*'):
+            with create_driver(driver_path, chrome_options, sw_options):
+                pass
 
 
 def test_har(driver_path, chrome_options, httpbin):
-    driver = create_driver(
-        driver_path,
-        chrome_options,
-        {'enable_har': True}
-    )
-    driver.get(f'{httpbin}/html')
+    with create_driver(driver_path, chrome_options, {'enable_har': True}) as driver:
+        driver.get(f'{httpbin}/html')
 
-    har = json.loads(driver.har)
+        har = json.loads(driver.har)
 
-    assert har['log']['creator']['comment'] == f'Selenium Wire version {seleniumwire.__version__}'
-    assert len(har['log']['entries']) == 1
-    assert har['log']['entries'][0]['request']['url'] == f'{httpbin}/html'
-    assert har['log']['entries'][0]['response']['status'] == 200
-
-    driver.quit()
+        assert har['log']['creator']['comment'] == f'Selenium Wire version {seleniumwire.__version__}'
+        assert len(har['log']['entries']) == 1
+        assert har['log']['entries'][0]['request']['url'] == f'{httpbin}/html'
+        assert har['log']['entries'][0]['response']['status'] == 200
 
 
 def test_disable_capture(driver_path, chrome_options, httpbin):
-    sw_options = {
-        'disable_capture': True
-    }
+    sw_options = {'disable_capture': True}
 
-    driver = create_driver(driver_path, chrome_options, sw_options)
-    driver.get(f'{httpbin}/html')
+    with create_driver(driver_path, chrome_options, sw_options) as driver:
+        driver.get(f'{httpbin}/html')
 
-    assert not driver.requests
+        assert not driver.requests
 
-    driver.quit()
+
+def test_switch_proxy_on_the_fly():
+    pass
