@@ -77,18 +77,15 @@ class BackendIntegrationTest(TestCase):
         self.assertEqual([], self.backend.storage.load_requests())
 
     def test_find(self):
-        self.make_request(
-            f'{self.httpbin}/anything/questions/tagged/django?page=2&sort=newest&pagesize=15')
-        self.make_request(
-            f'{self.httpbin}/anything/3.4/library/http.client.html')
+        self.make_request(f'{self.httpbin}/anything/questions/tagged/django?page=2&sort=newest&pagesize=15')
+        self.make_request(f'{self.httpbin}/anything/3.4/library/http.client.html')
 
         self.assertEqual(
             f'{self.httpbin}/anything/questions/tagged/django?page=2&sort=newest&pagesize=15',
-            self.backend.storage.find('/questions/tagged/django').url
+            self.backend.storage.find('/questions/tagged/django').url,
         )
         self.assertEqual(
-            f'{self.httpbin}/anything/3.4/library/http.client.html',
-            self.backend.storage.find('.*library.*').url
+            f'{self.httpbin}/anything/3.4/library/http.client.html', self.backend.storage.find('.*library.*').url
         )
 
     def test_get_request_body_empty(self):
@@ -119,9 +116,7 @@ class BackendIntegrationTest(TestCase):
 
     def test_set_header_overrides(self):
         user_agent = 'Test_User_Agent_String'
-        self.backend.modifier.headers = {
-            'User-Agent': user_agent
-        }
+        self.backend.modifier.headers = {'User-Agent': user_agent}
         self.make_request(f'{self.httpbin}/headers')
 
         last_request = self.backend.storage.load_last_request()
@@ -132,9 +127,7 @@ class BackendIntegrationTest(TestCase):
 
     def test_set_header_overrides_case_insensitive(self):
         user_agent = 'Test_User_Agent_String'
-        self.backend.modifier.headers = {
-            'user-agent': user_agent  # Lowercase header name
-        }
+        self.backend.modifier.headers = {'user-agent': user_agent}  # Lowercase header name
         self.make_request(f'{self.httpbin}/headers')
 
         last_request = self.backend.storage.load_last_request()
@@ -144,9 +137,7 @@ class BackendIntegrationTest(TestCase):
         self.assertEqual(user_agent, data['headers']['User-Agent'])
 
     def test_set_header_overrides_filters_out_header(self):
-        self.backend.modifier.headers = {
-            'User-Agent': None
-        }
+        self.backend.modifier.headers = {'User-Agent': None}
         self.make_request(f'{self.httpbin}/headers')
 
         last_request = self.backend.storage.load_last_request()
@@ -157,17 +148,13 @@ class BackendIntegrationTest(TestCase):
 
     def test_clear_header_overrides(self):
         user_agent = 'Test_User_Agent_String'
-        self.backend.modifier.headers = {
-            'User-Agent': user_agent
-        }
+        self.backend.modifier.headers = {'User-Agent': user_agent}
         del self.backend.modifier.headers
         self.make_request(f'{self.httpbin}/headers')
 
         last_request = self.backend.storage.load_last_request()
 
-        self.assertNotEqual(
-            user_agent, last_request.headers['User-Agent']
-        )
+        self.assertNotEqual(user_agent, last_request.headers['User-Agent'])
         data = json.loads(last_request.response.body.decode('utf-8'))
         self.assertNotEqual(user_agent, data['headers']['User-Agent'])
 
@@ -179,19 +166,12 @@ class BackendIntegrationTest(TestCase):
         last_request = self.backend.storage.load_last_request()
 
         params = {k: v[0] for k, v in parse_qs(urlsplit(last_request.url).query).items()}
-        self.assertEqual({
-            'foo': 'baz',
-            'spam': 'eggs'
-        }, params)
+        self.assertEqual({'foo': 'baz', 'spam': 'eggs'}, params)
 
     def test_set_param_overrides_post(self):
         self.backend.modifier.params = {'foo': 'baz'}
 
-        self.make_request(
-            f'{self.httpbin}/post',
-            method='POST',
-            data=b'foo=bazzz&spam=eggs'
-        )
+        self.make_request(f'{self.httpbin}/post', method='POST', data=b'foo=bazzz&spam=eggs')
 
         last_request = self.backend.storage.load_last_request()
 
@@ -288,10 +268,7 @@ class BackendIntegrationTest(TestCase):
         self.assertNotEqual(f'{self.httpbin}/anything/spam/bar', last_request.url)
 
     def test_set_multiples_scopes(self):
-        self.backend.scopes = (
-            f'{self.httpbin}/anything/foo/.*',
-            f'{self.httpbin}/anything/spam/.*'
-        )
+        self.backend.scopes = (f'{self.httpbin}/anything/foo/.*', f'{self.httpbin}/anything/spam/.*')
 
         self.make_request(f'{self.httpbin}/anything/foo/bar')
         last_request = self.backend.storage.load_last_request()
@@ -306,10 +283,7 @@ class BackendIntegrationTest(TestCase):
         self.assertNotEqual(f'{self.httpbin}/anything/hello/bar', last_request.url)
 
     def test_reset_scopes(self):
-        self.backend.scopes = (
-            f'{self.httpbin}/anything/foo/.*',
-            f'{self.httpbin}/anything/spam/.*'
-        )
+        self.backend.scopes = (f'{self.httpbin}/anything/foo/.*', f'{self.httpbin}/anything/spam/.*')
         self.backend.scopes = ()
 
         self.make_request(f'{self.httpbin}/anything/hello/bar')
@@ -318,9 +292,7 @@ class BackendIntegrationTest(TestCase):
     def test_disable_encoding(self):
         self.backend.options['disable_encoding'] = True
         # Explicitly set the accept-encoding to gzip
-        self.backend.modifier.headers = {
-            'Accept-Encoding': 'gzip'
-        }
+        self.backend.modifier.headers = {'Accept-Encoding': 'gzip'}
 
         self.make_request(f'{self.httpbin}/anything')
 
@@ -369,11 +341,7 @@ class BackendIntegrationTest(TestCase):
 
         self.backend.request_interceptor = interceptor
 
-        self.make_request(
-            f'{self.httpbin}/post',
-            method='POST',
-            data=b'{"foo": "bar", "spam": "eggs"}'
-        )
+        self.make_request(f'{self.httpbin}/post', method='POST', data=b'{"foo": "bar", "spam": "eggs"}')
 
         last_request = self.backend.storage.load_last_request()
 
@@ -435,17 +403,22 @@ class BackendIntegrationTest(TestCase):
         context.check_hostname = False
         context.verify_mode = ssl.CERT_NONE
         https_handler = urllib.request.HTTPSHandler(context=context)
-        proxy_handler = urllib.request.ProxyHandler({
-            'http': 'http://{}:{}'.format(host, port),
-            'https': 'http://{}:{}'.format(host, port),
-        })
+        proxy_handler = urllib.request.ProxyHandler(
+            {
+                'http': 'http://{}:{}'.format(host, port),
+                'https': 'http://{}:{}'.format(host, port),
+            }
+        )
         opener = urllib.request.build_opener(https_handler, proxy_handler)
         urllib.request.install_opener(opener)
 
     def make_request(self, url, method='GET', data=None):
         request = urllib.request.Request(url, method=method, data=data)
-        request.add_header('User-Agent', 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_6) AppleWebKit/537.36 '
-                                         '(KHTML, like Gecko) Chrome/66.0.3359.181 Safari/537.36')
+        request.add_header(
+            'User-Agent',
+            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_6) AppleWebKit/537.36 '
+            '(KHTML, like Gecko) Chrome/66.0.3359.181 Safari/537.36',
+        )
         with urllib.request.urlopen(request, timeout=5) as response:
             html = response.read()
 
